@@ -111,12 +111,11 @@ def test_tag_hashability():
     assert isinstance(Tag(''), Hashable)
 
 
-@pytest.mark.flaky(reruns=5)
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entries_from_fido_search_result(fido_search_result):
     entries = list(entries_from_fido_search_result(fido_search_result))
-    # 65 entries for 8 instruments in fido_search_result
-    assert len(entries) == 65
+    # 66 entries for 8 instruments in fido_search_result
+    assert len(entries) == 66
     # First 2 entries are from lyra
     assert entries[0] == DatabaseEntry(
         source='Proba2', provider='esa', physobs='irradiance',
@@ -136,9 +135,9 @@ def test_entries_from_fido_search_result(fido_search_result):
     # 2 entries from goes
     assert entries[56] == DatabaseEntry(
         source='nasa', provider='sdac', physobs='irradiance',
-        fileid='http://umbra.nascom.nasa.gov/goes/fits/2012/go1520120101.fits',
+        fileid='https://umbra.nascom.nasa.gov/goes/fits/2012/go1520120101.fits',
         observation_time_start=datetime(2012, 1, 1, 0, 0),
-        observation_time_end=datetime(2012, 1, 2, 0, 0),
+        observation_time_end=datetime(2012, 1, 1, 23, 59, 59, 999000),
         wavemin=np.nan, wavemax=np.nan,
         instrument='goes')
     # 1 entry from noaa-indices
@@ -166,7 +165,7 @@ def test_entries_from_fido_search_result(fido_search_result):
         observation_time_end=datetime(2012, 1, 2, 0, 0),
         wavemin=17634850.470588233, wavemax=17634850.470588233,
         instrument='NORH')
-    # 1 entry from rhessi
+    # 2 entries from rhessi
     assert entries[62] == DatabaseEntry(
         source="rhessi", provider='nasa', physobs='irradiance',
         fileid=("https://hesperia.gsfc.nasa.gov/"
@@ -176,7 +175,7 @@ def test_entries_from_fido_search_result(fido_search_result):
         wavemin=np.nan, wavemax=np.nan,
         instrument='rhessi')
     # 2 entries from eve, level 0
-    assert entries[63] == DatabaseEntry(
+    assert entries[64] == DatabaseEntry(
         source='SDO', provider='LASP', physobs='irradiance',
         fileid=("http://lasp.colorado.edu/eve/data_access/evewebdata/quicklook"
                 "/L0CS/SpWx/2012/20120101_EVE_L0CS_DIODES_1m.txt"),
@@ -186,7 +185,7 @@ def test_entries_from_fido_search_result(fido_search_result):
         instrument='eve')
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entries_from_fido_search_result_JSOC():
     search_result = Fido.search(
         net_attrs.jsoc.Time('2014-01-01T00:00:00', '2014-01-01T01:00:00'),
@@ -200,7 +199,7 @@ def test_entries_from_fido_search_result_JSOC():
         list(entries_from_fido_search_result(search_result))
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_from_fido_search_result_block(fido_search_result):
     entry = DatabaseEntry._from_fido_search_result_block(
         fido_search_result[0, 0][0].get_response(0)[0])
@@ -214,7 +213,7 @@ def test_from_fido_search_result_block(fido_search_result):
     assert entry == expected_entry
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entry_from_qr_block(query_result):
     entry = DatabaseEntry._from_query_result_block(query_result[0])
     expected_entry = DatabaseEntry(
@@ -226,7 +225,7 @@ def test_entry_from_qr_block(query_result):
     assert entry == expected_entry
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entry_from_qr_block_with_missing_physobs(qr_block_with_missing_physobs):
     entry = DatabaseEntry._from_query_result_block(
         qr_block_with_missing_physobs)
@@ -239,16 +238,18 @@ def test_entry_from_qr_block_with_missing_physobs(qr_block_with_missing_physobs)
     assert entry == expected_entry
 
 
-@pytest.mark.flaky(reruns=5)
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entry_from_qr_block_kev(qr_block_with_kev_unit):
     # See issue #766.
     entry = DatabaseEntry._from_query_result_block(qr_block_with_kev_unit)
     assert entry.source == 'RHESSI'
     assert entry.provider == 'LSSP'
-    assert entry.fileid == '/hessidata/2011/09/20/hsi_20110920_010920'
-    assert entry.observation_time_start == datetime(2011, 9, 20, 1, 9, 20)
-    assert entry.observation_time_end == datetime(2011, 9, 20, 2, 27, 40)
+    assert entry.fileid in ['/hessidata/2011/09/19/hsi_20110919_233340',
+                            '/hessidata/2011/09/20/hsi_20110920_010920']
+    assert entry.observation_time_start in [datetime(2011, 9, 20, 1, 9, 20),
+                                            datetime(2011, 9, 19, 23, 33, 40)]
+    assert entry.observation_time_end in [datetime(2011, 9, 20, 2, 27, 40),
+                                          datetime(2011, 9, 20, 1, 9, 20)]
     assert entry.instrument == 'RHESSI'
     assert entry.size == -1
     assert round(entry.wavemin, 3) == 0.413
@@ -406,17 +407,17 @@ def test_entries_from_dir_recursively_true():
     entries = list(entries_from_dir(testdir, True,
                                     default_waveunit='angstrom',
                                     time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 101
+    assert len(entries) == 102
 
 
 def test_entries_from_dir_recursively_false():
     entries = list(entries_from_dir(testdir, False,
                                     default_waveunit='angstrom',
                                     time_string_parse_format='%d/%m/%Y'))
-    assert len(entries) == 80
+    assert len(entries) == 81
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entries_from_query_result(query_result):
     entries = list(entries_from_query_result(query_result))
     assert len(entries) == 122
@@ -430,19 +431,19 @@ def test_entries_from_query_result(query_result):
     assert snd_entry == expected_entry
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entry_from_query_results_with_none_wave(qr_with_none_waves):
     # does not raise WaveunitNotFoundError because neither wavemin nor wavemax
     # are given
     list(entries_from_query_result(qr_with_none_waves))
 
 
-@pytest.mark.online
+@pytest.mark.remote_data
 def test_entry_from_query_results_with_none_wave_and_default_unit(
         qr_with_none_waves):
     entries = list(entries_from_query_result(qr_with_none_waves, 'nm'))
-    assert len(entries) == 4
-    assert entries == [
+    assert len(entries) == 10
+    expected = [
         DatabaseEntry(
             source='SOHO', provider='SDAC', physobs='intensity',
             fileid='/archive/soho/private/data/processed/virgo/level1/1212/HK/121222_1.H01',
@@ -470,8 +471,39 @@ def test_entry_from_query_results_with_none_wave_and_default_unit(
             observation_time_start=datetime(2012, 12, 24, 0, 1, 58),
             observation_time_end=datetime(2012, 12, 25, 0, 1, 57),
             instrument='VIRGO', size=14.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/sph/VIRGO_D4.2_SPH_960411_120914.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2012, 9, 14, 0, 0),
+            instrument='VIRGO', size=512000.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_blue_intensity_series.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2014, 3, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_green_intensity_series.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2014, 3, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
+            wavemax=None),
+        DatabaseEntry(
+            source='SOHO', provider='SDAC', physobs='intensity',
+            fileid='/archive/soho/private/data/processed/virgo/spm/SPM_red_intensity_series.tar.gz',
+            observation_time_start=datetime(1996, 4, 11, 0, 0),
+            observation_time_end=datetime(2014, 3, 30, 23, 59),
+            instrument='VIRGO', size=32652.0, wavemin=None,
             wavemax=None)]
 
+    for e in expected:
+        assert e in entries
+
 
 def test_create_display_table_missing_entries():
     with pytest.raises(TypeError):
